gorippled

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2021 License: MIT Imports: 5 Imported by: 0

README

Go Rippled

Build Status Go Report Card Docs License

This package is designed to providerippled server utilities including:

  • OpenAPI specifcation: partial OAS3 specification files are provided
  • Simple JSON RPC request handling

Models

Test Client

A test API client is provided that executes the requests on XRPL.org.

Display example request:

$ cd cmd/rippledapiexample
$ go run main.go --method account_info

Display example request and response:

$ cd cmd/rippledapiexample
$ go run main.go --method account_info --exec

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DoApiJsonRpcSplit

func DoApiJsonRpcSplit(jrpcURL, rippledMethod string, paramsBodyBytes []byte) (*http.Response, error)

DoApiJsonRpcSplit sends a JSON RPC API request to the specified `rippled` server using an API method and request params.

Types

type JsonRpcRequest

type JsonRpcRequest struct {
	Method string                   `json:"method"`
	Params []map[string]interface{} `json:"params"`
}

func BuildJsonRpcRequestBody

func BuildJsonRpcRequestBody(rippledMethod string, paramsBodyBytes []byte) (JsonRpcRequest, error)

BuildJsonRpcRequestBody merges a `rippled` API methid with JSON RPC API request params.

Directories

Path Synopsis
cmd
Code generated for package main by go-bindata DO NOT EDIT.
Code generated for package main by go-bindata DO NOT EDIT.

Jump to